Learn R Programming

scientific (version 2025.1)

newthought: Scientific handout formats (PDF and HTML)

Description

Template for creating scientific handout

Usage

newthought(text)

margin_note(text, icon = "⊕")

quote_footer(text)

sans_serif(text)

html(..., template = "template1")

Value

an HTML notebook output based on the R markdown document provided

Arguments

text

A character string to be presented as a “new thought” (using small caps), or a margin note, or a footer of a quote

icon

A character string to indicate there is a hidden margin note when the page width is too narrow (by default it is a circled plus sign)

...

Other arguments to be passed to [html_document()] (note you cannot use the `theme` argument in `html()`; this arguments have been set internally)

template

template name to use

Details

`newthought()` can be used in inline R expressions in R Markdown ```r `r newthought(Some text)` ``` and it works for both HTML (<span class="newthought">text</span>) and PDF (\newthought{text}) output.

`margin_note()` can be used in inline R expressions to write a margin note (like a sidenote but not numbered).

`quote_footer()` formats text as the footer of a quote. It puts `text` in <footer></footer> for HTML output, and after \hfill for LaTeX output (to right-align text).

`sans_serif()` applies sans-serif fonts to `text`.

`handout()` provides the PDF format

`html()` provides the HTML format based on the scientific CSS

Examples

Run this code
newthought("In this section")
if (FALSE) {
# for Rmd to HTML
library(rmarkdown)
library(scientific)
rmdfile <- "input.Rmd"
rmarkdown::render(rmdfile,
  scientific::html(
    toc = TRUE,
    toc_depth = 2))
}

Run the code above in your browser using DataLab