`newthought()` can be used in inline R expressions in R
Markdown
```r
`r newthought(Some text)`
```
and it works for both
HTML (<span class="newthought">text</span>) and PDF
(\newthought{text}) output.
`margin_note()` can be used in inline R expressions to write a
margin note (like a sidenote but not numbered).
`quote_footer()` formats text as the footer of a quote. It puts
`text` in <footer></footer> for HTML output, and
after \hfill for LaTeX output (to right-align text).
`sans_serif()` applies sans-serif fonts to `text`.
`handout()` provides the PDF format
`html()` provides the HTML format based on the scientific CSS